UserAttributes class
- Implementers
Constructors
- UserAttributes({String? email, String? phone, String? password, Object? data})
Properties
- data ↔ Object?
-
A custom data object to store the user's metadata. This maps to the
auth.users.user_metadatacolumn.getter/setter pair - email ↔ String?
-
The user's email.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- password ↔ String?
-
The user's password.
getter/setter pair
- phone ↔ String?
-
The user's phone.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited